// Copyright 2022 System76 <info@system76.com>
// SPDX-License-Identifier: GPL-2.0

#include <config.h>
#include <gtk/gtk.h>
#include <stdint.h>
#include <pop_analytics_panel.h>
#include "shell/cc-application.h"
#include "cc-analytics-panel.h"

struct _CcAnalyticsPanel {
    CcPanel    parent_instance;
};

CC_PANEL_REGISTER (CcAnalyticsPanel, cc_analytics_panel)

static void cc_analytics_panel_dispose (GObject *object) {
    G_OBJECT_CLASS (cc_analytics_panel_parent_class)->dispose (object);
}

static void cc_analytics_panel_finalize (GObject *object) {
    G_OBJECT_CLASS (cc_analytics_panel_parent_class)->finalize (object);
}

static void cc_analytics_panel_class_init (CcAnalyticsPanelClass *klass) {
    GObjectClass *object_class = G_OBJECT_CLASS (klass);

    object_class->dispose = cc_analytics_panel_dispose;
    object_class->finalize = cc_analytics_panel_finalize;
}

static gboolean attach_panel (GtkContainer *self) {
    GtkWindow *window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self)));

    pop_analytics_panel_attach (self, window);
    gtk_widget_show_all (GTK_WIDGET (self));

    return FALSE;
}

static void cc_analytics_panel_init (CcAnalyticsPanel *self) {
    pop_analytics_panel_init ();

    // Attach after idling so we'll have access to the window as a toplevel.
    g_idle_add ((GSourceFunc) attach_panel, GTK_CONTAINER (self));
}

void cc_analytics_panel_static_init_func (void) {
  CcApplication *application;

  if (!pop_analytics_panel_should_show ())
    {
      application = CC_APPLICATION (g_application_get_default ());
      cc_shell_model_set_panel_visibility (cc_application_get_model (application),
                                           "analytics",
                                           CC_PANEL_HIDDEN);
    }
}
